#
# spec file for package pcsc-asedriveiiie-usb
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %( pkg-config --modversion udev ) > 190
%define _udevprefix /usr/lib
%else
%define _udevprefix /lib
%endif

Name:           pcsc-asedriveiiie-usb
%define _name asedriveiiie-usb
Summary:        ASEDrive IIIe USB Smart Card Reader Driver
License:        BSD-3-Clause
Group:          Productivity/Security
Version:        3.7
Release:        12.5
%define tar_version 3-7
URL:            http://www.asedrive.com/downloads
Source:         %{_name}-%{tar_version}-tar.bz2
# PATCH-FIX-OPENSUSE asedriveiiie-usb-destdir.patch sbrabec@suse.cz -- Fix destdir installation.
Patch1:         asedriveiiie-usb-destdir.patch
Patch2:         pcscd-group-no-longer-exist.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libusb-devel
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
# for directory ownership
BuildRequires:  pkgconfig(udev)
Requires:       pcsc-lite
Supplements:    modalias(usb:v0DC3p0802d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0DC3p1104d*dc*dsc*dp*ic*isc*ip*)
%define ifddir %(pkg-config libpcsclite --variable=usbdropdir)

%description
This package contains a driver for the ASEDrive IIIe USB smart card
reader.

This driver is meant to be used with the PCSC-Lite daemon from the
pcsc-lite package.

%prep
%autosetup -p1 -n %{_name}-%{version}

chmod -x ChangeLog LICENSE README

%build
%configure
make %{?jobs:-j%jobs} CC="%__cc" LD="%__ld" CPP="%__cpp" CXX="%__cxx"

%install
%makeinstall
# Move udev rules provided by packages to %%{_udevprefix}
mkdir -p $RPM_BUILD_ROOT%{_udevprefix}/
mv $RPM_BUILD_ROOT/etc/udev $RPM_BUILD_ROOT%{_udevprefix}/

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc ChangeLog LICENSE README
%{ifddir}/ifd-ASEDriveIIIe-USB.bundle
%{_udevprefix}/udev/rules.d/*.rules

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allo OBS to
  shortcut through -mini flavors.
* Sun Jun 12 2016 opensuse.lietuviu.kalba@gmail.com
- Fix: pcscd is started as root (boo#942847,
  pcscd-group-no-longer-exist.patch)
* Sat Jan 12 2013 reddwarf@opensuse.org
- Fix udev rules moving from /etc to (/usr)/lib
* Thu Oct 18 2012 fcrozat@suse.com
- Fix build with new udev rules directory location
* Thu Jul 12 2012 sbrabec@suse.cz
- Update to version 3.7:
  * IFDHSetProtocolParameters does nothing when the protocol need
    not be changed.
* Wed Apr  8 2009 sbrabec@suse.cz
- Added USB modalias supplements.
- Require pcsc-lite.
* Wed Aug  1 2007 sbrabec@suse.cz
- New SuSE package, version 3.5 (FATE#301086).
